import { useStorage } from '@vueuse/core'
import type { CrmVariant } from '~/src/shared/model'
import { useCRMGetCart } from '~/src/shared/api/crm/crm'

export function useProductPrice(variants: CrmVariant[], id: string) {
  const amount = ref(0)
  const currentUnitPrice = ref(0)
  const prevUnitPrice = ref()
  const { mutateAsync, data } = useCRMGetCart()

  const addedItems = useStorage<{
    id: string
    count: number
  }[]>('added-items', [])

  const storageProduct = computed(() => addedItems.value.find(item => item.id === id))

  const setInitCurrentPrice = () => {
    currentUnitPrice.value = Number(variants[0].price) / 100
  }

  watch(amount, async (value, oldValue) => {
    await mutateAsync({
      data: [
        {
          count: String(value),
          productId: id,
        },
      ],
    })

    const newCurrent = Number(data.value?.data.amount) / 100 || 0
    const newPrev = Number(data.value?.data.amountOld) / 100 || 0

    currentUnitPrice.value = newCurrent

    if (newCurrent !== newPrev) {
      prevUnitPrice.value = newPrev
    }
    else {
      prevUnitPrice.value = undefined
    }

    if (value === 0) {
      addedItems.value = addedItems.value.filter(item => item.id !== id)

      setInitCurrentPrice()

      return
    }

    if (storageProduct.value) {
      storageProduct.value.count = value
      return
    }

    addedItems.value.push({
      id,
      count: value,
    })
  })

  if (storageProduct.value) {
    amount.value = storageProduct.value.count
  }
  else {
    setInitCurrentPrice()
  }

  return {
    amount,
    currentUnitPrice,
    prevUnitPrice,
  }
}
